@@ -1,3 +1,4 @@
+use crate::webhandler::WebHandler;
 use crate::websocket::WebSocketHandler;
 use crate::{Endpoints, Server};
 
@@ -24,7 +25,18 @@ impl Builder {
         path: &'static str,
         handler: impl WebSocketHandler + 'static,
     ) -> Builder {
-        self.endpoints.insert(path, Box::new(handler));
+        self.endpoints
+            .insert_websocket_handler(path, Box::new(handler));
+
+        Builder { ..self }
+    }
+
+    pub fn for_web_path(
+        mut self,
+        path: &'static str,
+        handler: impl WebHandler + 'static,
+    ) -> Builder {
+        self.endpoints.insert_web_handler(path, Box::new(handler));
 
         Builder { ..self }
     }
