@@ -15,6 +15,7 @@ use futures::{SinkExt, StreamExt};
 use tokio::net::TcpStream;
 use tokio::sync::mpsc::error::SendError;
 use tokio::sync::mpsc::{UnboundedReceiver, UnboundedSender};
+use tracing::{error, trace, trace_span, warn};
 use tracing_futures::Instrument;
 use uuid::Uuid;
 
@@ -32,23 +33,23 @@ pub(crate) async fn register_recv_ws_message_handling(
                     Ok(msg) => server.recv(session_id, msg).await,
                     Err(e) => {
                         let error_message = format!("Receive from websocket: {:?}", e);
-                        tracing::error!("{}", error_message);
+                        error!("{}", error_message);
 
                         let frame = CloseFrame {
                             code: CloseCode::Abnormal,
                             reason: std::borrow::Cow::Owned(error_message),
                         };
 
-                        tracing::warn!("Dropping channel 'ws_session_rx' -> server::recv()");
+                        warn!("Dropping channel 'ws_session_rx' -> server::recv()");
                         server.recv(session_id, Message::Close(Some(frame))).await;
                         return;
                     }
                 }
             }
 
-            tracing::warn!("we are leaving the gibson - channel dropped");
+            warn!("we are leaving the gibson - channel dropped");
         }
-        .instrument(tracing::trace_span!("recv_from_ws_task")),
+        .instrument(trace_span!("recv_from_ws_task")),
     );
 }
 
@@ -60,15 +61,15 @@ pub(crate) async fn register_send_to_ws_message_handling(
     tokio::spawn(
         async move {
             while let Some(result) = rx.recv().await {
-                tracing::trace!("Sending to websocket: {:?}", result);
+                trace!("Sending to websocket: {:?}", result);
                 if let Err(e) = ws_session_tx.send(result).await {
-                    tracing::error!("Sending to websocket: {:?}", e);
-                    tracing::warn!("Dropping channel server -> 'ws_session_rx'");
+                    error!("Sending to websocket: {:?}", e);
+                    warn!("Dropping channel server -> 'ws_session_rx'");
                     return;
                 }
             }
         }
-        .instrument(tracing::trace_span!("send_to_ws_task")),
+        .instrument(trace_span!("send_to_ws_task")),
     );
 }
 
@@ -142,6 +143,15 @@ impl ConnectionContext {
         }
     }
 
+    pub(crate) fn from_parts(parts: hyper::http::request::Parts) -> Self {
+        let query = match parts.uri.query() {
+            Some(s) => s.to_string(),
+            _ => String::with_capacity(0),
+        };
+
+        ConnectionContext::new(None, parts.headers, query, parts.uri.path().to_owned())
+    }
+
     pub fn addr(&self) -> Option<SocketAddr> {
         self.addr
     }
